# mini-pandas

Custom implementation of `pandas` library<br><br>
Supports DataFrames and various commonly used functionalities such as:<br>
multiple column selection, aggregating and grouping, pivoting, reading and analyzing csv files etc.<br><br>

Requires python>=3.11
